User guide
==========

This User Guide is a tour of the options available for contouring.  These equate to keyword
arguments that are passed to the :func:`~contourpy.contour_generator` function.

Before reading this you should check out the :ref:`quickstart`.

The other main source of information is the :ref:`api`.

.. toctree::
   :maxdepth: 1

   name
   z_corner_mask
   x_and_y
   chunks
   line_type
   fill_type
   quad_as_tri
   z_interp
   threads
